Learn R Programming

RedditExtractoR (version 3.0.1)

get_user_content: Find data relating to a Reddit user

Description

Given a valid Reddit user name, obtain a list consisting of general information about the user, their comments and threads

Usage

get_user_content(user)

Arguments

user

A string representing a valid Reddit user name

Value

A list with "about" (list), "comments" (data frame) and "threads" (data frame)

Examples

Run this code
# NOT RUN {
get_user_content("memes")
# }

Run the code above in your browser using DataLab