powered by
Given a valid Reddit user name, obtain a list consisting of general information about the user, their comments and threads
get_user_content(user)
A string representing a valid Reddit user name
A list with "about" (list), "comments" (data frame) and "threads" (data frame)
# NOT RUN { get_user_content("memes") # }
Run the code above in your browser using DataLab